svn commit: r19880 - trunk/src/argouml-app/src/org/argouml/ui/ProjectBrowser.java

[email protected] Tue, 24 Apr 2012 05:40:57 -0700 (PDT)
Newsgroups gmane.comp.lang.uml.argouml.cvs
Message-ID <[email protected]>
Author: mvw
Date: 2012-04-24 05:40:56-0700
New Revision: 19880

Modified:
   trunk/src/argouml-app/src/org/argouml/ui/ProjectBrowser.java

Log:
Add some logging for a sporadic failure on Sharepoint mediums.


Modified: trunk/src/argouml-app/src/org/argouml/ui/ProjectBrowser.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src/argouml-app/src/org/argouml/ui/ProjectBrowser.java?view=diff&pathrev=19880&r1=19879&r2=19880
==============================================================================
--- trunk/src/argouml-app/src/org/argouml/ui/ProjectBrowser.java	(original)
+++ trunk/src/argouml-app/src/org/argouml/ui/ProjectBrowser.java	2012-04-24 05:40:56-0700
@@ -1197,6 +1197,7 @@
 
             // does the file really exists?
             if (!file.exists()) {
+                LOG.warn("Project file not found - URI: " + uri);
                 // project file doesn't exist. let's pop up a message dialog..
                 int response = JOptionPane.showConfirmDialog(
                         this,
@@ -1564,7 +1565,8 @@
      *               false if run in commandline mode
      * @param pmw 	the ProgressMonitor to be updated;  
      * 				if not needed, use null 
      * @return true if the file was successfully opened
      * 
      * TODO: Separate this into a Swing specific class - tfm
      */

------------------------------------------------------
@@ -1564,7 +1565,8 @@
      * @param pmw 	the ProgressMonitor to be updated;  
      * 				if not needed, use null 
-     * @return true if the file was successfully opened
+     * @return project the project that was created based on the file that was
+     *                 successfully opened
      * 
      * TODO: Separate this into a Swing specific class - tfm
http://argouml.tigris.org/ds/viewMessage.do?dsForumId=5905&dsMessageId=2951465

To unsubscribe from this discussion, e-mail: [[email protected]].